@@ -74,7 +74,8 @@ typedef enum
 {
     SHOW_ICON_ALWAYS,
     SHOW_ICON_WHEN_BATTERY_PRESENT,
-    SHOW_ICON_WHEN_BATTERY_CHARGING_DISCHARGING
+    SHOW_ICON_WHEN_BATTERY_CHARGING_DISCHARGING,
+    NEVER_SHOW_ICON
     
 } XfpmShowIcon;
 
