@@ -38,14 +38,6 @@ typedef enum
     
 } SystemFormFactor;
 
-typedef enum
-{
-    SHOW_ICON_ALWAYS,
-    SHOW_ICON_WHEN_BATTERY_PRESENT,
-    SHOW_ICON_WHEN_BATTERY_CHARGING_DISCHARGING
-    
-} XfpmShowIcon;
-
 typedef enum
 {
     LID_KEY   		= (1 << 0),
