@@ -175,7 +175,7 @@ xfpm_xfconf_property_changed_cb (XfconfChannel *channel, gchar *property,
     if ( G_VALUE_TYPE(value) == G_TYPE_INVALID )
         return;
 
-    if ( !g_str_has_prefix (property, PROPERTIES_PREFIX) )
+    if ( !g_str_has_prefix (property, PROPERTIES_PREFIX) || strlen (property) <= strlen (PROPERTIES_PREFIX) )
 	return;
 
     TRACE("Property modified: %s\n", property);
@@ -237,7 +237,7 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                      PROP_CRITICAL_LEVEL,
                                      g_param_spec_uint (CRITICAL_POWER_LEVEL,
                                                         NULL, NULL,
-							0,
+							5,
 							20,
 							10,
                                                         G_PARAM_READWRITE));
